import React from "react";
import PropTypes from "prop-types";
import ForwardComponent from "./ForwardComponent";
import { useParams } from "react-router";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import { loadSessionForwards } from "../../../session/actionCreators";
import Spinner from "../../../../components/common/Spinner";
import styles from "../../../../components/common/styles/divStyles";
import { useTranslation } from "react-i18next";
import { makeStyles } from "@material-ui/core/styles";

const useStyles = makeStyles(styles);

const ForwardContainer = ({ actions, forward }) => {
  const params = useParams();
  const classes = useStyles();
  const { t } = useTranslation();

  const { sessionId } = params;

  if (!forward) {
    actions.loadSessionForwards(sessionId);
    return <Spinner />;
  }

  return (
    <div className={classes.root}>
      <h3>{t("Forward.Title", forward)}</h3>
      <ForwardComponent forward={forward} />
    </div>
  );
};

ForwardContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  forward: PropTypes.object
};

function mapStateToProps(state, props) {
  const { sessionId, forwardId } = props.match.params;
  const session = state.forwards[sessionId];
  const forward = session?.find(z => (z.forwardId = forwardId));

  return {
    forward
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators({ loadSessionForwards }, dispatch)
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(ForwardContainer);
