import React, { useState } from "react";
import PropTypes from "prop-types";
import styles from "../../../../../../components/common/styles/expandableCardStyles";
import { makeStyles } from "@material-ui/core/styles";
import {
  Card,
  CardHeader,
  CardContent,
  CardActions,
  Collapse,
  Avatar,
  IconButton
} from "@material-ui/core";
import { useTranslation } from "react-i18next";
import SurroundSoundRoundedIcon from "@material-ui/icons/SurroundSoundRounded";
import clsx from "clsx";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import KeyOverwriteSummary from "./KeyOverwriteSummary";

const useStyles = makeStyles(styles);

const KeyOverwriteCard = ({ data }) => {
  const [expanded, setExpanded] = useState(false);

  const classes = useStyles();
  const { t } = useTranslation();

  const handleExpandClick = () => {
    setExpanded(!expanded);
  };

  return (
    <Card>
      <CardHeader
        avatar={
          <Avatar aria-label="recipe" className={classes.avatar}>
            <SurroundSoundRoundedIcon />
          </Avatar>
        }
        action={
          <IconButton
            className={clsx(classes.expand, {
              [classes.expandOpen]: expanded
            })}
            onClick={handleExpandClick}
            aria-expanded={expanded}
            aria-label="show more"
          >
            <ExpandMoreIcon />
          </IconButton>
        }
        title={<strong>{t("Server.ActiveSession")}</strong>}
        subheader={t("Server.ActiveSessionSubtitle")}
      />
      <CardContent>
        <KeyOverwriteSummary data={data} />
      </CardContent>
      <CardActions disableSpacing></CardActions>
      <Collapse in={expanded} timeout="auto" unmountOnExit>
        <CardContent>
          <div>CONTENT...</div>
        </CardContent>
      </Collapse>
    </Card>
  );
};

KeyOverwriteCard.propTypes = {
  data: PropTypes.object.isRequired
};

export default KeyOverwriteCard;
